==> kmymoney_3.98.1.orig.tar.gz: kmymoney-3.98.1/kmymoney/plugins/printcheck/numbertowords.h <==
/***************************************************************************
 *   Copyright 2009  Cristian Onet onet.cristian@gmail.com                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef __NUMBERTOWORDS_H__
#define __NUMBERTOWORDS_H__

#include <QStringList>

#include <kmymoney/mymoneymoney.h>

class MyMoneyMoneyToWordsConverter
{
private:
  QString convertTreeDigitGroup(int threeDigitNumber);

public:
  MyMoneyMoneyToWordsConverter();
  QString convert(const MyMoneyMoney & money);

private:
  QStringList m_smallNumbers;
  QStringList m_tens;
  QStringList m_scaleNumbers;
};

#endif // __NUMBERTOWORDS_H__

==> kmymoney_4.5.3.orig.tar.gz: kmymoney-4.5.3/kmymoney/plugins/printcheck/numbertowords.h <==
/***************************************************************************
 *   Copyright 2009  Cristian Onet onet.cristian@gmail.com                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef NUMBERTOWORDS_H
#define NUMBERTOWORDS_H

#include <QStringList>

#include <kmymoney/mymoneymoney.h>

class MyMoneyMoneyToWordsConverter
{
private:
  QString convertTreeDigitGroup(int threeDigitNumber);

public:
  MyMoneyMoneyToWordsConverter();
  QString convert(const MyMoneyMoney & money);

private:
  QStringList m_smallNumbers;
  QStringList m_tens;
  QStringList m_scaleNumbers;
};

#endif // NUMBERTOWORDS_H
